@@ -284,6 +284,7 @@ ImageRecipeTypeDef = TypedDict(
         "blockDeviceMappings": List["InstanceBlockDeviceMappingTypeDef"],
         "dateCreated": str,
         "tags": Dict[str, str],
+        "workingDirectory": str,
     },
     total=False,
 )
@@ -377,6 +378,7 @@ InfrastructureConfigurationSummaryTypeDef = TypedDict(
         "description": str,
         "dateCreated": str,
         "dateUpdated": str,
+        "resourceTags": Dict[str, str],
         "tags": Dict[str, str],
     },
     total=False,
@@ -398,6 +400,7 @@ InfrastructureConfigurationTypeDef = TypedDict(
         "snsTopicArn": str,
         "dateCreated": str,
         "dateUpdated": str,
+        "resourceTags": Dict[str, str],
         "tags": Dict[str, str],
     },
     total=False,
